.. _algorithm:

dooku.algorithm
===============

This part of Dooku contains various algorithms that are missed in Python's
standard library and here they are:


all_of
-------

.. autofunction:: dooku.algorithm.all_of

any_of
------

.. autofunction:: dooku.algorithm.any_of

find_if
-------

.. autofunction:: dooku.algorithm.find_if

none_of
-------

.. autofunction:: dooku.algorithm.none_of
